@@ -239,7 +239,7 @@ pub struct AgedPosition {
     pub lat: f64,
     pub lon: f64,
     pub nic: u8,
-    pub rc: u16,
+    pub rc: u32,
 }
 
 // "ARA": "1100001",
@@ -369,7 +369,7 @@ pub struct Aircraft {
 
     pub nac_v: Option<u8>,
 
-    pub nav_altitude_fms: Option<u16>,
+    pub nav_altitude_fms: Option<i32>,
 
     pub nav_altitude_mcp: Option<i32>,
 
@@ -441,7 +441,7 @@ pub struct Aircraft {
     pub wind_direction: Option<u16>,
 
     #[serde(rename = "ws")]
-    pub wind_speed: Option<u16>,
+    pub wind_speed: Option<u32>,
 }
 
 /// The ADS-B Exchange API response. This has most of the info you want :)
